#[non_exhaustive]pub enum Request<'a> {
GetSwipeGesture {
pointer: WlPointer,
},
GetPinchGesture {
pointer: WlPointer,
},
Release,
GetHoldGesture {
pointer: WlPointer,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GetSwipeGesture
get swipe gesture
Create a swipe gesture object. See the wl_pointer_gesture_swipe interface for details.
GetPinchGesture
get pinch gesture
Create a pinch gesture object. See the wl_pointer_gesture_pinch interface for details.
Release
destroy the pointer gesture object
Destroy the pointer gesture object. Swipe, pinch and hold objects created via this gesture object remain valid.
This is a destructor, once sent this object cannot be used any longer. Only available since version 2 of the interface
GetHoldGesture
get hold gesture
Create a hold gesture object. See the wl_pointer_gesture_hold interface for details.
Only available since version 3 of the interface
Implementations