pub struct ZwpPointerGesturesV1 { /* private fields */ }Expand description
touchpad gestures
A global interface to provide semantic touchpad gestures for a given pointer.
Three gestures are currently supported: swipe, pinch, and hold. Pinch and swipe gestures follow a three-stage cycle: begin, update, end. Hold gestures follow a two-stage cycle: begin and end. All gestures are identified by a unique id.
Warning! The protocol described in this file is experimental and backward incompatible changes may be made. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes are done by bumping the version number in the protocol and interface names and resetting the interface version. Once the protocol is to be declared stable, the ‘z’ prefix and the version number in the protocol and interface names are removed and the interface version number is reset.
This interface has no events.
Implementations
Sourceimpl ZwpPointerGesturesV1
impl ZwpPointerGesturesV1
Sourcepub fn get_swipe_gesture<U, D: 'static>(
&self,
pointer: &WlPointer,
qh: &QueueHandle<D>,
udata: U,
) -> ZwpPointerGestureSwipeV1
pub fn get_swipe_gesture<U, D: 'static>( &self, pointer: &WlPointer, qh: &QueueHandle<D>, udata: U, ) -> ZwpPointerGestureSwipeV1
get swipe gesture
Create a swipe gesture object. See the wl_pointer_gesture_swipe interface for details.
Sourcepub fn get_pinch_gesture<U, D: 'static>(
&self,
pointer: &WlPointer,
qh: &QueueHandle<D>,
udata: U,
) -> ZwpPointerGesturePinchV1
pub fn get_pinch_gesture<U, D: 'static>( &self, pointer: &WlPointer, qh: &QueueHandle<D>, udata: U, ) -> ZwpPointerGesturePinchV1
get pinch gesture
Create a pinch gesture object. See the wl_pointer_gesture_pinch interface for details.
Sourcepub fn release(&self)
pub fn release(&self)
destroy the pointer gesture object
Destroy the pointer gesture object. Swipe, pinch and hold objects created via this gesture object remain valid.
Sourcepub fn get_hold_gesture<U, D: 'static>(
&self,
pointer: &WlPointer,
qh: &QueueHandle<D>,
udata: U,
) -> ZwpPointerGestureHoldV1
pub fn get_hold_gesture<U, D: 'static>( &self, pointer: &WlPointer, qh: &QueueHandle<D>, udata: U, ) -> ZwpPointerGestureHoldV1
get hold gesture
Create a hold gesture object. See the wl_pointer_gesture_hold interface for details.